@@ -4,10 +4,10 @@
 #include <pbbam/Config.h>
 
 #include <pbbam/BamRecord.h>
-#include <pbbam/Orientation.h>
-#include <pbbam/Position.h>
 
 #include <pbcopper/data/GenomicInterval.h>
+#include <pbcopper/data/Orientation.h>
+#include <pbcopper/data/Position.h>
 
 #include <memory>
 #include <stdexcept>
