@@ -96,9 +96,10 @@ struct PbiFile
     ///
     /// \throws std::runtime_error if index file could not be created
     ///
-    static void CreateFrom(const BamFile& bamFile, PbiBuilder::CompressionLevel compressionLevel =
-                                                       PbiBuilder::DefaultCompression,
-                           size_t numThreads = 4);
+    static void CreateFrom(
+        const BamFile& bamFile,
+        PbiBuilder::CompressionLevel compressionLevel = PbiBuilder::DefaultCompression,
+        size_t numThreads = 4);
 };
 
 }  // namespace BAM
