@@ -3,14 +3,14 @@
 
 #include <pbbam/Config.h>
 
-#include <cstddef>
-#include <cstdint>
+#include <pbbam/PbiFile.h>
 
 #include <memory>
 #include <string>
 #include <vector>
 
-#include <pbbam/PbiFile.h>
+#include <cstddef>
+#include <cstdint>
 
 namespace PacBio {
 namespace BAM {
@@ -139,6 +139,10 @@ public:
     std::vector<uint32_t> nM_;
     std::vector<uint32_t> nMM_;
     std::vector<uint8_t> mapQV_;
+    std::vector<uint32_t> nInsOps_;
+    std::vector<uint32_t> nDelOps_;
+
+    bool hasIndelOps_ = true;
 
     /// \}
 };
@@ -333,7 +337,7 @@ public:
     /// \returns true if index has \b section
     /// \param[in] section PbiFile::Section identifier
     ///
-    bool HasSection(const PbiFile::Section section) const;
+    bool HasSection(PbiFile::Section section) const;
 
     /// \returns index filename ("*.pbi")
     ///
