@@ -3,11 +3,11 @@
 
 #include <pbbam/Config.h>
 
-#include <cstdint>
+#include <pbbam/internal/QueryBase.h>
 
 #include <vector>
 
-#include <pbbam/internal/QueryBase.h>
+#include <cstdint>
 
 namespace PacBio {
 namespace BAM {
@@ -37,7 +37,9 @@ public:
     ///
     ZmwQuery(std::vector<int32_t> zmwWhitelist, const DataSet& dataset);
 
-    ~ZmwQuery();
+    ZmwQuery(ZmwQuery&&) noexcept;
+    ZmwQuery& operator=(ZmwQuery&&) noexcept;
+    ~ZmwQuery() override;
 
     /// \brief Main iteration point for record access.
     ///
