@@ -3,9 +3,10 @@
 
 #include <pbbam/Config.h>
 
-#include <pbbam/Position.h>
 #include <pbbam/vcf/VcfHeaderTypes.h>
 
+#include <pbcopper/data/Position.h>
+
 #include <optional>
 #include <string>
 #include <unordered_map>
