@@ -2,8 +2,6 @@
 
 #include "BamRecordTags.h"
 
-#include <cassert>
-
 #include <unordered_map>
 
 namespace PacBio {
@@ -21,6 +19,8 @@ const BamRecordTags::TagLookupType BamRecordTags::tagLookup =
     { BamRecordTag::CONTEXT_FLAGS,            {"cx", false} },
     { BamRecordTag::DELETION_QV,              {"dq", false} },
     { BamRecordTag::DELETION_TAG,             {"dt", false} },
+    { BamRecordTag::FORWARD_IPD,              {"fi", false} },
+    { BamRecordTag::FORWARD_PW,               {"fp", false} },
     { BamRecordTag::HOLE_NUMBER,              {"zm", false} },
     { BamRecordTag::INSERTION_QV,             {"iq", false} },
     { BamRecordTag::IPD,                      {"ip", false} },
@@ -38,6 +38,8 @@ const BamRecordTags::TagLookupType BamRecordTags::tagLookup =
     { BamRecordTag::PULSE_EXCLUSION,          {"pe", true}  },
     { BamRecordTag::PULSE_MERGE_QV,           {"pg", true}  },
     { BamRecordTag::PULSE_WIDTH,              {"pw", false} }, // 'pulse' in the name; but stored per-base, not per-pulse
+    { BamRecordTag::REVERSE_IPD,              {"ri", false} },
+    { BamRecordTag::REVERSE_PW,               {"rp", false} },
     { BamRecordTag::QUERY_END,                {"qe", false} },
     { BamRecordTag::QUERY_END_FRAME_NUMBER,   {"we", false} },
     { BamRecordTag::QUERY_START,              {"qs", false} },
@@ -46,10 +48,16 @@ const BamRecordTags::TagLookupType BamRecordTags::tagLookup =
     { BamRecordTag::READ_GROUP,               {"RG", false} },
     { BamRecordTag::SCRAP_REGION_TYPE,        {"sc", false} },
     { BamRecordTag::SCRAP_ZMW_TYPE,           {"sz", false} },
+    { BamRecordTag::SEGMENT_ADAPTER_LEFT,     {"dl", false} },
+    { BamRecordTag::SEGMENT_ADAPTER_RIGHT,    {"dr", false} },
+    { BamRecordTag::SEGMENT_INDEX,            {"di", false} },
+    { BamRecordTag::SEGMENT_SUPPLEMENTAL,     {"ds", false} },
     { BamRecordTag::SIGNAL_TO_NOISE,          {"sn", false} },
     { BamRecordTag::START_FRAME,              {"sf", true}  },
     { BamRecordTag::SUBSTITUTION_QV,          {"sq", false} },
     { BamRecordTag::SUBSTITUTION_TAG,         {"st", false} },
+    { BamRecordTag::BASEMOD_LOCI,             {"MM", false} },
+    { BamRecordTag::BASEMOD_QV,               {"ML", false} },
 
     // faux tags
     { BamRecordTag::SEQ,  {"  ",  false} },
