@@ -2,29 +2,17 @@
 
 #include <pbbam/FastaSequence.h>
 
-#include <cassert>
-#include <cstdio>
+#include <boost/algorithm/string.hpp>
 
 #include <exception>
 #include <tuple>
 #include <type_traits>
 
-#include <boost/algorithm/string.hpp>
+#include <cstdio>
 
 namespace PacBio {
 namespace BAM {
 
-static_assert(std::is_copy_constructible<FastaSequence>::value,
-              "FastaSequence(const FastaSequence&) is not = default");
-static_assert(std::is_copy_assignable<FastaSequence>::value,
-              "FastaSequence& operator=(const FastaSequence&) is not = default");
-
-static_assert(std::is_nothrow_move_constructible<FastaSequence>::value,
-              "FastaSequence(FastaSequence&&) is not = noexcept");
-static_assert(std::is_nothrow_move_assignable<FastaSequence>::value ==
-                  std::is_nothrow_move_assignable<std::string>::value,
-              "");
-
 FastaSequence::FastaSequence(std::string name, std::string bases)
     : name_{std::move(name)}, bases_{std::move(bases)}
 {
