@@ -2,19 +2,19 @@
 
 #include "FileUtils.h"
 
-#include <sys/stat.h>
-#include <unistd.h>
+#include <pbbam/StringUtilities.h>
 
-#include <cassert>
-#include <cstddef>
+#include <boost/algorithm/string.hpp>
 
 #include <memory>
 #include <sstream>
 #include <stdexcept>
 
-#include <boost/algorithm/string.hpp>
+#include <cassert>
+#include <cstddef>
 
-#include <pbbam/StringUtilities.h>
+#include <sys/stat.h>
+#include <unistd.h>
 
 namespace PacBio {
 namespace BAM {
@@ -52,7 +52,7 @@ static std::string removeDiskName(const std::string& filePath)
     return filePath;
 }
 
-static const char native_pathSeparator = '\\';
+constexpr char NATIVE_PATH_SEPARATOR = '\\';
 
 static bool native_pathIsAbsolute(const std::string& filePath)
 {
@@ -98,14 +98,14 @@ static std::string native_resolvedFilePath(const std::string& filePath, const st
 
     const bool thisDirAtStart = (schemeLess.find(".") == 0);
     if (thisDirAtStart) {
-        if (schemeLess.find(native_pathSeparator) == 1) schemeLess = schemeLess.substr(2);
+        if (schemeLess.find(NATIVE_PATH_SEPARATOR) == 1) schemeLess = schemeLess.substr(2);
     }
-    return from + native_pathSeparator + schemeLess;
+    return from + NATIVE_PATH_SEPARATOR + schemeLess;
 }
 
 #else  // else for non-Windows systems
 
-static const char native_pathSeparator = '/';
+constexpr char NATIVE_PATH_SEPARATOR = '/';
 
 static bool native_pathIsAbsolute(const std::string& filePath) { return filePath.at(0) == '/'; }
 
@@ -116,7 +116,9 @@ static std::string native_resolvedFilePath(const std::string& filePath, const st
 
     // if empty or already absolute path, just return it
     // upfront empty check simplifies further parsing logic
-    if (schemeLess.empty() || native_pathIsAbsolute(schemeLess)) return schemeLess;
+    if (schemeLess.empty() || native_pathIsAbsolute(schemeLess)) {
+        return schemeLess;
+    }
 
     // else make relative from the provided 'from' directory
     //
@@ -127,9 +129,11 @@ static std::string native_resolvedFilePath(const std::string& filePath, const st
     //
     const bool thisDirAtStart = (schemeLess.find(".") == 0);
     if (thisDirAtStart) {
-        if (schemeLess.find(native_pathSeparator) == 1) schemeLess = schemeLess.substr(2);
+        if (schemeLess.find(NATIVE_PATH_SEPARATOR) == 1) {
+            schemeLess = schemeLess.substr(2);
+        }
     }
-    return from + native_pathSeparator + schemeLess;
+    return from + NATIVE_PATH_SEPARATOR + schemeLess;
 }
 
 #endif  // PBBAM_WIN_FILEPATHS
@@ -144,22 +148,28 @@ std::string FileUtils::CurrentWorkingDirectory()
 
     // stack-based buffer for 'normal' case
     char buffer[chunkSize];
-    if (getcwd(buffer, sizeof(buffer)) != nullptr) return std::string(buffer);
+    if (getcwd(buffer, sizeof(buffer)) != nullptr) {
+        return std::string(buffer);
+    }
 
     // if error is not ERANGE, then it's not a problem of too-long name... something else happened
-    if (errno != ERANGE)
+    if (errno != ERANGE) {
         throw std::runtime_error{
             "[pbbam] file utilities ERROR: could not determine current working directory path"};
+    }
 
     // long path - use heap, trying progressively longer buffers
     for (size_t chunks = 2; chunks < maxNumChunks; ++chunks) {
-        std::unique_ptr<char> cwd(new char[chunkSize * chunks]);
-        if (getcwd(cwd.get(), chunkSize * chunks) != nullptr) return std::string(cwd.get());
+        auto cwd = std::make_unique<char[]>(chunkSize * chunks);
+        if (getcwd(cwd.get(), chunkSize * chunks) != nullptr) {
+            return std::string(cwd.get());
+        }
 
         // if error is not ERANGE, then it's not a problem of too-long name... something else happened
-        if (errno != ERANGE)
+        if (errno != ERANGE) {
             throw std::runtime_error{
                 "[pbbam] file utilities ERROR: could not determine current working directory path"};
+        }
     }
 
     // crazy long path name
@@ -171,7 +181,9 @@ std::string FileUtils::CurrentWorkingDirectory()
 std::string FileUtils::DirectoryName(const std::string& file)
 {
     const auto found = file.rfind(Separator(), file.length());
-    if (found != std::string::npos) return file.substr(0, found);
+    if (found != std::string::npos) {
+        return file.substr(0, found);
+    }
     return std::string(".");
 }
 
@@ -198,7 +210,7 @@ std::string FileUtils::ResolvedFilePath(const std::string& filePath, const std::
     return native_resolvedFilePath(filePath, from);
 }
 
-constexpr char FileUtils::Separator() { return native_pathSeparator; }
+char FileUtils::Separator() { return NATIVE_PATH_SEPARATOR; }
 
 off_t FileUtils::Size(const char* fn)
 {
