@@ -3,14 +3,15 @@
 
 #include <pbbam/Config.h>
 
-#include <cstdio>
+#include "IndexedFastqReaderImpl.h"
+
+#include <pbcopper/utility/Deleters.h>
+
+#include <htslib/kseq.h>
 
 #include <memory>
 
-#include <htslib/kseq.h>
-#include <pbcopper/utility/Deleters.h>
-
-#include "IndexedFastqReaderImpl.h"
+#include <cstdio>
 
 namespace PacBio {
 namespace BAM {
@@ -38,7 +39,9 @@ private:
     {
         void operator()(kseq_t* seq) const noexcept
         {
-            if (seq) kseq_destroy(seq);
+            if (seq) {
+                kseq_destroy(seq);
+            }
             seq = nullptr;
         }
     };
