@@ -2,16 +2,16 @@
 
 #include "Version.h"
 
+#include <pbbam/StringUtilities.h>
+
 #include <ostream>
 #include <sstream>
 #include <stdexcept>
 
-#include <pbbam/StringUtilities.h>
-
 namespace PacBio {
 namespace BAM {
 
-const Version Version::Current = Version(3, 0, 7);
+const Version Version::Current = Version(5, 0, 0);
 const Version Version::Minimum = Version(3, 0, 1);
 
 // string must be "<major>.<minor>.<version>"
@@ -21,12 +21,15 @@ Version::Version(const std::string& v) : major_{0}, minor_{0}, revision_{0}
     try {
         const auto fields = Split(v, '.');
         const auto numFields = fields.size();
-        if (numFields == 0)
+        if (numFields == 0) {
             throw std::runtime_error{"[pbbam] version string parsing ERROR: empty string"};
+        }
         major_ = std::stoi(fields.at(0));
         if (numFields > 1) {
             minor_ = std::stoi(fields.at(1));
-            if (numFields > 2) revision_ = std::stoi(fields.at(2));
+            if (numFields > 2) {
+                revision_ = std::stoi(fields.at(2));
+            }
         }
     } catch (std::exception& e) {
         std::ostringstream msg;
