@@ -5,7 +5,7 @@
 
 #include <gtest/gtest.h>
 
-#include <pbbam/GenomicInterval.h>
+#include <pbcopper/data/GenomicInterval.h>
 
 #include "PbbamTestData.h"
 
@@ -18,7 +18,7 @@ namespace BedReaderTests {
 const std::string BedFn = PacBio::BAM::PbbamTestsConfig::Data_Dir + "/bed/test.bed";
 const std::string GzipBedFn = PacBio::BAM::PbbamTestsConfig::Data_Dir + "/bed/test.bed.gz";
 
-const std::vector<PacBio::BAM::GenomicInterval> ExpectedIntervals {
+const std::vector<PacBio::Data::GenomicInterval> ExpectedIntervals {
     {"chr1", 213941196, 213942363},
     {"chr1", 213942363, 213943530},
     {"chr1", 213943530, 213944697},
@@ -34,7 +34,7 @@ void CheckManualIteration(const std::string& fn)
 {
     size_t count = 0;
     BedReader reader{fn};
-    PacBio::BAM::GenomicInterval interval;
+    PacBio::Data::GenomicInterval interval;
     while (reader.GetNext(interval)) {
         EXPECT_EQ(BedReaderTests::ExpectedIntervals.at(count), interval);
         ++count;
