@@ -1,5 +1,3 @@
-// Author: Derek Barnett
-
 #include <pbbam/DataSet.h>
 
 #include <cstddef>
@@ -31,19 +29,19 @@ static DataSet CreateDataSet()
 TEST(BAM_DataSetCore, can_parse_xml_name_parts)
 {
     internal::XmlName name{"ns:node_name"};
-    EXPECT_EQ(boost::string_ref("ns"), name.Prefix());
-    EXPECT_EQ(boost::string_ref("node_name"), name.LocalName());
-    EXPECT_EQ(boost::string_ref("ns:node_name"), name.QualifiedName());
+    EXPECT_EQ("ns", name.Prefix());
+    EXPECT_EQ("node_name", name.LocalName());
+    EXPECT_EQ("ns:node_name", name.QualifiedName());
 
     internal::XmlName bareName{"node_name"};
-    EXPECT_EQ(boost::string_ref(""), bareName.Prefix());
-    EXPECT_EQ(boost::string_ref("node_name"), bareName.LocalName());
-    EXPECT_EQ(boost::string_ref("node_name"), bareName.QualifiedName());
+    EXPECT_EQ("", bareName.Prefix());
+    EXPECT_EQ("node_name", bareName.LocalName());
+    EXPECT_EQ("node_name", bareName.QualifiedName());
 
     internal::XmlName leadingColon{":node_name"};
-    EXPECT_EQ(boost::string_ref(""), leadingColon.Prefix());
-    EXPECT_EQ(boost::string_ref(":node_name"), leadingColon.LocalName());
-    EXPECT_EQ(boost::string_ref(":node_name"), leadingColon.QualifiedName());
+    EXPECT_EQ("", leadingColon.Prefix());
+    EXPECT_EQ(":node_name", leadingColon.LocalName());
+    EXPECT_EQ(":node_name", leadingColon.QualifiedName());
 }
 
 TEST(BAM_DataSetCore, created_with_correct_defaults)
@@ -181,10 +179,11 @@ TEST(BAM_DataSetCore, can_add_external_resources)
     // iterable
     size_t i = 0;
     for (auto r : resources) {
-        if (i == 0)
+        if (i == 0) {
             EXPECT_EQ("file1", r.Name());
-        else
+        } else {
             EXPECT_EQ("file2", r.Name());
+        }
         ++i;
     }
 }
@@ -434,10 +433,11 @@ TEST(BAM_DataSetCore, can_add_subdatasets)
     // iterable
     size_t i = 0;
     for (const DataSetBase& ds : subdatasets) {
-        if (i == 0)
+        if (i == 0) {
             EXPECT_EQ("subset_1", ds.Name());
-        else
+        } else {
             EXPECT_EQ("subset_2", ds.Name());
+        }
         ++i;
     }
 }
@@ -468,10 +468,11 @@ TEST(BAM_DataSetCore, can_edit_subdatasets)
     // iterable
     size_t i = 0;
     for (const DataSetBase& ds : subdatasets) {
-        if (i == 0)
+        if (i == 0) {
             EXPECT_EQ("subset_1_edited", ds.Name());
-        else
+        } else {
             EXPECT_EQ("subset_2", ds.Name());
+        }
         ++i;
     }
 }
@@ -554,3 +555,101 @@ TEST(BAM_DataSetCore, can_load_biosamples_from_xml)
     ASSERT_EQ(1, biosamples.Size());
     EXPECT_EQ("test test", biosamples[0].Name());
 }
+
+TEST(BAM_DataSetCore, can_fetch_samples)
+{
+    const std::set<std::string> expected = {"sample1", "sample2"};
+    const BAM::DataSet dataset{PbbamTestsConfig::Data_Dir +
+                               "/dataset/samples/dataset_sample_test.subreadset.xml"};
+    EXPECT_EQ(dataset.BamFilenames().size(), 3);
+    EXPECT_EQ(dataset.Samples(), expected);
+}
+
+TEST(BAM_DataSetCore, can_add_supplemental_resources)
+{
+    DataSet dataset;
+    EXPECT_EQ(0, dataset.SupplementalResources().Size());
+
+    ExternalResource resource1{"metatype", "id"};
+    resource1.Name("file1");
+
+    ExternalResource resource2{"metatype", "id2"};
+    resource2.Name("file2");
+
+    dataset.SupplementalResources().Add(resource1);
+    dataset.SupplementalResources().Add(resource2);
+    EXPECT_EQ(2, dataset.SupplementalResources().Size());
+
+    // disallow duplicates (checking on ResourceId)
+    const ExternalResource duplicateResource{"metatype", "id"};
+    dataset.SupplementalResources().Add(duplicateResource);
+    EXPECT_EQ(2, dataset.SupplementalResources().Size());
+
+    // direct access
+    const SupplementalResources& resources = dataset.SupplementalResources();
+    ASSERT_EQ(2, resources.Size());
+    EXPECT_EQ("file1", resources[0].Name());
+    EXPECT_EQ("file2", resources[1].Name());
+
+    // iterable
+    size_t i = 0;
+    for (auto r : resources) {
+        if (i == 0) {
+            EXPECT_EQ("file1", r.Name());
+        } else {
+            EXPECT_EQ("file2", r.Name());
+        }
+        ++i;
+    }
+}
+
+TEST(BAM_DataSetCore, can_edit_supplemental_resources)
+{
+    DataSet dataset;
+
+    ExternalResource resource{"metatype", "id"};
+    resource.Name("file1");
+    dataset.SupplementalResources().Add(resource);
+
+    resource.Name("file2").ResourceId("id2");
+    dataset.SupplementalResources().Add(resource);
+    EXPECT_EQ(2, dataset.SupplementalResources().Size());
+
+    // edit
+    dataset.SupplementalResources()[0].Name("some new name");
+    EXPECT_EQ("some new name", dataset.SupplementalResources()[0].Name());
+    EXPECT_EQ("file2", dataset.SupplementalResources()[1].Name());
+}
+
+TEST(BAM_DataSetCore, can_remove_supplemental_resources)
+{
+    DataSet dataset;
+    EXPECT_EQ(0, dataset.SupplementalResources().Size());
+
+    ExternalResource resource1{"metatype", "id"};
+    resource1.Name("file1");
+
+    ExternalResource resource2{"metatype", "id2"};
+    resource2.Name("file2");
+
+    dataset.SupplementalResources().Add(resource1);
+    dataset.SupplementalResources().Add(resource2);
+    EXPECT_EQ(2, dataset.SupplementalResources().Size());
+
+    // remove
+    dataset.SupplementalResources().Remove(resource1);
+    EXPECT_EQ(1, dataset.SupplementalResources().Size());
+
+    // direct access
+    const SupplementalResources& resources = dataset.SupplementalResources();
+    EXPECT_EQ("file2", resources[0].Name());
+
+    // iterable
+    size_t i = 0;
+    for (auto r : resources) {
+        if (i == 0) {
+            EXPECT_EQ("file2", r.Name());
+        }
+        ++i;
+    }
+}
