@@ -13,7 +13,7 @@ TEST(BAM_FastqSequence, BasicConstructorsOk)
     EXPECT_EQ("[[[[[[[", seq1.Qualities().Fastq());
 
     const std::vector<uint8_t> quals{58, 58, 58, 58, 58, 58, 58};
-    const FastqSequence seq2{"1", "GATTACA", QualityValues{quals}};
+    const FastqSequence seq2{"1", "GATTACA", Data::QualityValues{quals}};
     EXPECT_EQ("1", seq2.Name());
     EXPECT_EQ("GATTACA", seq2.Bases());
     EXPECT_EQ("[[[[[[[", seq2.Qualities().Fastq());
