@@ -73,7 +73,7 @@ TEST(BAM_IndexedFastaReader, can_fetch_subsequence_from_lambda)
     EXPECT_EQ(1, r.NumSequences());
     EXPECT_EQ(48502, r.SequenceLength("lambda_NEB3011"));
 
-    std::string seq = r.Subsequence("lambda_NEB3011:0-10");
+    std::string seq = r.Subsequence("lambda_NEB3011:1-10");
     EXPECT_EQ("GGGCGGCGAC", seq);
 
     std::string seq2 = r.Subsequence("lambda_NEB3011", 0, 10);
@@ -99,48 +99,48 @@ TEST(BAM_IndexedFastaReader, prints_clipped_and_gapped_subsequences_from_lambda)
     auto it = bamQuery.begin();
     auto record = *it++;
     EXPECT_EQ("GGCTGCAGTGTACAGCGGTCAGGAGGCC-ATTGATGCCGGACTGGCTGAT",
-              r.ReferenceSubsequence(record, Orientation::NATIVE, true));
+              r.ReferenceSubsequence(record, Data::Orientation::NATIVE, true));
     EXPECT_EQ("GGCTGCAGTGTACAGCGGTCAGGAGGCC-ATTGATGCCGGACTGGCTGAT",
-              r.ReferenceSubsequence(record, Orientation::NATIVE, true, true));
+              r.ReferenceSubsequence(record, Data::Orientation::NATIVE, true, true));
     EXPECT_EQ("GGCTGCAGTGTACAGCGGTCAGGAGGCC-ATTGATGCCGGACTGGCTGAT",
-              r.ReferenceSubsequence(record, Orientation::GENOMIC, true));
+              r.ReferenceSubsequence(record, Data::Orientation::GENOMIC, true));
     EXPECT_EQ("GGCTGCAGTGTACAGCGGTCAGGAGGCC-ATTGATGCCGGACTGGCTGAT",
-              r.ReferenceSubsequence(record, Orientation::GENOMIC, true, true));
+              r.ReferenceSubsequence(record, Data::Orientation::GENOMIC, true, true));
     record = *it++;
     EXPECT_EQ("GGCTGCAGTGTACAGCGGTCAGGAGGCC-ATTGATGCCGGACTGGCTGAT",
-              r.ReferenceSubsequence(record, Orientation::NATIVE, true));
+              r.ReferenceSubsequence(record, Data::Orientation::NATIVE, true));
     EXPECT_EQ("GGCTGCAGTGTACAGCGGTCAGGAGGCC-ATTGATGCCGGACTGGCTGAT",
-              r.ReferenceSubsequence(record, Orientation::NATIVE, true, true));
+              r.ReferenceSubsequence(record, Data::Orientation::NATIVE, true, true));
     EXPECT_EQ("GGCTGCAGTGTACAGCGGTCAGGAGGCC-ATTGATGCCGGACTGGCTGAT",
-              r.ReferenceSubsequence(record, Orientation::GENOMIC, true));
+              r.ReferenceSubsequence(record, Data::Orientation::GENOMIC, true));
     EXPECT_EQ("GGCTGCAGTGTACAGCGGTCAGGAGGCC-ATTGATGCCGGACTGGCTGAT",
-              r.ReferenceSubsequence(record, Orientation::GENOMIC, true, true));
+              r.ReferenceSubsequence(record, Data::Orientation::GENOMIC, true, true));
     record = *it++;
     EXPECT_EQ(
         "----------------------------------------------------"
         "AAGTCACCAATGTGGGACGTCCGTCGATGGCAGAAGATCGCAGCACGGT-AACAGCGGCAA",
-        r.ReferenceSubsequence(record, Orientation::NATIVE, true));
+        r.ReferenceSubsequence(record, Data::Orientation::NATIVE, true));
     EXPECT_EQ("AAGTCACCAATGTGGGACGTCCGTCGATGGCAGAAGATCGCAGCACGGT-AACAGCGGCAA",
-              r.ReferenceSubsequence(record, Orientation::NATIVE, true, true));
+              r.ReferenceSubsequence(record, Data::Orientation::NATIVE, true, true));
     EXPECT_EQ(
         "----------------------------------------------------"
         "AAGTCACCAATGTGGGACGTCCGTCGATGGCAGAAGATCGCAGCACGGT-AACAGCGGCAA",
-        r.ReferenceSubsequence(record, Orientation::GENOMIC, true));
+        r.ReferenceSubsequence(record, Data::Orientation::GENOMIC, true));
     EXPECT_EQ("AAGTCACCAATGTGGGACGTCCGTCGATGGCAGAAGATCGCAGCACGGT-AACAGCGGCAA",
-              r.ReferenceSubsequence(record, Orientation::GENOMIC, true, true));
+              r.ReferenceSubsequence(record, Data::Orientation::GENOMIC, true, true));
     record = *it++;
     EXPECT_EQ(
         "AAGTCACCAATGTGGGACGTCCGTCGATGGCAGAAGATCGCAGCACGGT-AACAGCGGCAA-----------------------------"
         "-----------------------",
-        r.ReferenceSubsequence(record, Orientation::GENOMIC, true));
+        r.ReferenceSubsequence(record, Data::Orientation::GENOMIC, true));
     EXPECT_EQ(
         "----------------------------------------------------TTGCCGCTGTT-"
         "ACCGTGCTGCGATCTTCTGCCATCGACGGACGTCCCACATTGGTGACTT",
-        r.ReferenceSubsequence(record, Orientation::NATIVE, true));
+        r.ReferenceSubsequence(record, Data::Orientation::NATIVE, true));
     EXPECT_EQ("AAGTCACCAATGTGGGACGTCCGTCGATGGCAGAAGATCGCAGCACGGT-AACAGCGGCAA",
-              r.ReferenceSubsequence(record, Orientation::GENOMIC, true, true));
+              r.ReferenceSubsequence(record, Data::Orientation::GENOMIC, true, true));
     EXPECT_EQ("TTGCCGCTGTT-ACCGTGCTGCGATCTTCTGCCATCGACGGACGTCCCACATTGGTGACTT",
-              r.ReferenceSubsequence(record, Orientation::NATIVE, true, true));
+              r.ReferenceSubsequence(record, Data::Orientation::NATIVE, true, true));
 }
 
 // Come back
