@@ -22,7 +22,7 @@ TEST(VCF_VcfVariant, default_ctor_provides_proper_default_values)
     VcfVariant v;
 
     EXPECT_TRUE(v.Chrom().empty());
-    EXPECT_EQ(PacBio::BAM::UnmappedPosition, v.Position());
+    EXPECT_EQ(PacBio::Data::UNMAPPED_POSITION, v.Position());
     EXPECT_TRUE(v.Id().empty());
     EXPECT_TRUE(v.RefAllele().empty());
     EXPECT_TRUE(v.AltAllele().empty());
